aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/GrYUVProvider.h
diff options
context:
space:
mode:
authorGravatar Robert Phillips <robertphillips@google.com>2017-03-08 14:32:55 -0500
committerGravatar Skia Commit-Bot <skia-commit-bot@chromium.org>2017-03-08 22:37:42 +0000
commit538f1a36e3cd0327ee2639693143179ec0359151 (patch)
treed7bb0d1a15e23e952038967f87a69185d981c07f /src/gpu/GrYUVProvider.h
parentf141fff87abdc68d1a5adba6ea77d1885952ca5b (diff)
Switch GrYUVProvider over to GrTextureProxies
This is split out of: https://skia-review.googlesource.com/c/8823/ (Remove GrFragmentProcessor-derived class' GrTexture-based ctors) Change-Id: I302e6b4c1ffed449a990288ec06f2dfdcdadf1f8 Reviewed-on: https://skia-review.googlesource.com/9448 Reviewed-by: Brian Salomon <bsalomon@google.com> Commit-Queue: Robert Phillips <robertphillips@google.com>
Diffstat (limited to 'src/gpu/GrYUVProvider.h')
-rw-r--r--src/gpu/GrYUVProvider.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gpu/GrYUVProvider.h b/src/gpu/GrYUVProvider.h
index c32af15df0..ef3ae6dd7e 100644
--- a/src/gpu/GrYUVProvider.h
+++ b/src/gpu/GrYUVProvider.h
@@ -28,14 +28,14 @@ public:
virtual ~GrYUVProvider() {}
/**
* On success, this returns a texture that has converted the YUV data from the provider
* into a form that is supported by the GPU (typically transformed into RGB). If useCache
* is true, then the texture will automatically have a key added, so it can be retrieved
* from the cache (assuming it is requested by a provider w/ the same genID).
*
* On failure (e.g. the provider had no data), this returns NULL.
*/
- sk_sp<GrTexture> refAsTexture(GrContext*, const GrSurfaceDesc&, bool useCache);
+ sk_sp<GrTextureProxy> refAsTextureProxy(GrContext*, const GrSurfaceDesc&, bool useCache);
virtual uint32_t onGetID() = 0;
@@ -28,14 +28,14 @@ public:
virtual ~GrYUVProvider() {}
/**
- * On success, this returns a texture that has converted the YUV data from the provider
+ * On success, this returns a texture proxy that has converted the YUV data from the provider
* into a form that is supported by the GPU (typically transformed into RGB). If useCache
* is true, then the texture will automatically have a key added, so it can be retrieved